==> pygit2-1.14.0.tar.gz: pygit2-1.14.0/AUTHORS.md <==
Authors:

    J. David Ibáñez
    Carlos Martín Nieto
    Nico von Geyso
    Iliyas Jorio
    Sviatoslav Sydorenko
    Matthias Bartelmeß
    Robert Coup
    W. Trevor King
    Drew DeVault
    Dave Borowitz
    Brandon Milton
    Daniel Rodríguez Troitiño
    Peter Rowlands
    Richo Healey
    Christian Boos
    Julien Miotte
    Nick Hynes
    Richard Möhn
    Xu Tao
    Matthew Duggan
    Matthew Gamble
    Jeremy Westwood
    Jose Plana
    Martin Lenders
    Sriram Raghu
    Victor Garcia
    Yonggang Luo
    Patrick Steinhardt
    Petr Hosek
    Tamir Bahar
    Valentin Haenel
    Xavier Delannoy
    Michael Jones
    Saugat Pachhai
    Bernardo Heynemann
    John Szakmeister
    Nabijacz Leweli
    Simon Cozens
    Vlad Temian
    Brodie Rao
    Chad Dombrova
    Lukas Fleischer
    Mathias Leppich
    Nicolas Dandrimont
    Raphael Medaer (Escaux)
    Anatoly Techtonik
    Andrew Olsen
    Dan Sully
    David Versmisse
    Grégory Herrero
    Mikhail Yushkovskiy
    Robin Stocker
    Rohit Sanjay
    Rémi Duraffort
    Santiago Perez De Rosso
    Sebastian Thiel
    Thom Wiggers
    William Manley
    Alexander Linne
    Alok Singhal
    Assaf Nativ
    Bob Carroll
    Christian Häggström
    Erik Johnson
    Filip Rindler
    Fraser Tweedale
    Grégoire ROCHER
    Han-Wen Nienhuys
    Helio Machado
    Jason Ziglar
    Leonardo Rhodes
    Mark Adams
    Nika Layzell
    Peter-Yi Zhang
    Petr Viktorin
    Robert Hölzl
    Ron Cohen
    Sebastian Böhm
    Sukhman Bhuller
    Thomas Kluyver
    Tyler Cipriani
    Alex Chamberlain
    Alexander Bayandin
    Amit Bakshi
    Andrey Devyatkin
    Arno van Lumig
    Ben Davis
    Colin Watson
    Dan Yeaw
    Dustin Raimondi
    Eric Schrijver
    Greg Fitzgerald
    Guillermo Pérez
    Hervé Cauwelier
    Hong Minhee
    Huang Huang
    Ian P. McCullough
    Igor Gnatenko
    Insomnia
    Jack O'Connor
    Jared Flatow
    Jeremy Heiner
    Jesse P. Johnson
    Jiunn Haur Lim
    Jorge C. Leitao
    Jun Omae
    Kaarel Kitsemets
    Ken Dreyer
    Kevin KIN-FOO
    Marcel Waldvogel
    Masud Rahman
    Michael Sondergaard
    Natanael Arndt
    Ondřej Nový
    Sarath Lakshman
    Steve Kieffer
    Szucs Krisztian
    Vicent Marti
    Zbigniew Jędrzejewski-Szmek
    Zoran Zaric
    nikitalita
    Adam Gausmann
    Adam Spiers
    Albin Söderström
    Alexandru Fikl
    Andrew Chin
    Andrey Trubachev
    András Veres-Szentkirályi
    Ash Berlin
    Benjamin Kircher
    Benjamin Pollack
    Benjamin Wohlwend
    Bogdan Stoicescu
    Bogdan Vasilescu
    Bryan O'Sullivan
    CJ Harries
    Cam Cope
    Chad Birch
    Chason Chaffin
    Chris Jerdonek
    Chris Rebert
    Christopher Hunt
    Claudio Jolowicz
    Craig de Stigter
    Cristian Hotea
    Cyril Jouve
    Dan Cecile
    Daniel Bruce
    Daniele Esposti
    Daniele Trifirò
    David Black
    David Fischer
    David Sanders
    David Six
    Dennis Schwertel
    Devaev Maxim
    Eric Davis
    Erik Meusel
    Erik van Zijst
    Fabrice Salvaire
    Ferengee
    Frazer McLean
    Gustavo Di Pietro
    Holger Frey
    Hugh Cole-Baker
    Isabella Stephens
    Jacob Swanson
    Jasper Lievisse Adriaanse
    Jimisola Laursen
    Jiri Benc
    Jonathan Robson
    Josh Bleecher Snyder
    Julia Evans
    Justin Clift
    Konstantinos Smanis
    Kyriakos Oikonomakos
    Lance Eftink
    Legorooj
    Lukas Berk
    Martin von Zweigbergk
    Mathieu Bridon
    Mathieu Parent
    Mathieu Pillard
    Matthaus Woolard
    Michał Górny
    Nicolás Sanguinetti
    Nikita Kartashov
    Nikolai Zujev
    Noah Fontes
    Óscar San José
    Patrick Lühne
    Paul Wagland
    Peter Dave Hello
    Phil Schleihauf
    Philippe Ombredanne
    Ram Rachum
    Remy Suen
    Ridge Kennedy
    Rodrigo Bistolfi
    Ross Nicoll
    Rui Abreu Ferreira
    Sandro Jäckel
    Saul Pwanson
    Shane Turner
    Sheeo
    Simone Mosciatti
    Soasme
    Steven Winfield
    Tad Hardesty
    Timo Röhling
    Vladimir Rutsky
    Yu Jianjian
    buhl
    chengyuhang
    earl
    odidev

==> pygit2-1.19.1.tar.gz: pygit2-1.19.1/AUTHORS.md <==
Authors:

    J. David Ibáñez
    Carlos Martín Nieto
    Nico von Geyso
    Iliyas Jorio
    Benedikt Seidl
    Sviatoslav Sydorenko
    Matthias Bartelmeß
    Robert Coup
    W. Trevor King
    Drew DeVault
    Dave Borowitz
    Brandon Milton
    Daniel Rodríguez Troitiño
    Brendan Doherty
    Peter Rowlands
    Richo Healey
    Christian Boos
    Julien Miotte
    Nick Hynes
    Richard Möhn
    Xu Tao
    Konstantin Baikov
    Matthew Duggan
    Matthew Gamble
    Jeremy Westwood
    Jose Plana
    Martin Lenders
    Sriram Raghu
    Victor Garcia
    Yonggang Luo
    Łukasz Langa
    Patrick Steinhardt
    Petr Hosek
    Tamir Bahar
    Valentin Haenel
    Xavier Delannoy
    Michael Jones
    Saugat Pachhai
    Andrej730
    Bernardo Heynemann
    John Szakmeister
    Nabijacz Leweli
    Simon Cozens
    Vlad Temian
    Brodie Rao
    Chad Dombrova
    Lukas Fleischer
    Mathias Leppich
    Mathieu Parent
    Michał Kępień
    Nicolas Dandrimont
    Raphael Medaer
    Yaroslav Halchenko
    Anatoly Techtonik
    Andrew Olsen
    Dan Sully
    David Versmisse
    Grégory Herrero
    Mikhail Yushkovskiy
    Robin Stocker
    Rohit Sanjay
    Rémi Duraffort
    Santiago Perez De Rosso
    Sebastian Thiel
    Thom Wiggers
    WANG Xuerui
    William Manley
    Alexander Linne
    Alok Singhal
    Assaf Nativ
    Bob Carroll
    Christian Häggström
    Edmundo Carmona Antoranz
    Erik Johnson
    Filip Rindler
    Fraser Tweedale
    Grégoire ROCHER
    Han-Wen Nienhuys
    Helio Machado
    Jason Ziglar
    Leonardo Rhodes
    Mark Adams
    Nika Layzell
    Peter-Yi Zhang
    Petr Viktorin
    Robert Hölzl
    Ron Cohen
    Sebastian Böhm
    Sukhman Bhuller
    Thomas Kluyver
    Tyler Cipriani
    Alex Chamberlain
    Alexander Bayandin
    Amit Bakshi
    Andrey Devyatkin
    Arno van Lumig
    Ben Davis
    CJ Steiner
    Colin Watson
    Craig de Stigter
    Dan Yeaw
    Dustin Raimondi
    Eric Schrijver
    Greg Fitzgerald
    Guillermo Pérez
    Hervé Cauwelier
    Hong Minhee
    Huang Huang
    Ian P. McCullough
    Igor Gnatenko
    Insomnia
    Jack O'Connor
    Jared Flatow
    Jeremy Heiner
    Jesse P. Johnson
    Jiunn Haur Lim
    Jorge C. Leitao
    Jun Omae
    Kaarel Kitsemets
    Ken Dreyer
    Kevin KIN-FOO
    Kyle Gottfried
    Marcel Waldvogel
    Masud Rahman
    Michael Sondergaard
    Natanael Arndt
    Ondřej Nový
    Sarath Lakshman
    Steve Kieffer
    Szucs Krisztian
    Vicent Marti
    Zbigniew Jędrzejewski-Szmek
    Zoran Zaric
    nikitalita
    Adam Gausmann
    Adam Spiers
    Adrien Nader
    Albin Söderström
    Alexandru Fikl
    Andrew Chin
    Andrew McNulty
    Andrey Trubachev
    András Veres-Szentkirályi
    Ash Berlin
    Benjamin Kircher
    Benjamin Pollack
    Benjamin Wohlwend
    Bogdan Stoicescu
    Bogdan Vasilescu
    Bryan O'Sullivan
    CJ Harries
    Cam Cope
    Chad Birch
    Chason Chaffin
    Chris Jerdonek
    Chris Rebert
    Christopher Hunt
    Claudio Jolowicz
    Cristian Hotea
    Cyril Jouve
    Dan Cecile
    Daniel Bruce
    Daniele Esposti
    Daniele Trifirò
    David Black
    David Fischer
    David Sanders
    David Six
    Dennis Schwertel
    Devaev Maxim
    Eric Davis
    Erik Meusel
    Erik van Zijst
    Fabrice Salvaire
    Ferengee
    Florian Weimer
    Frazer McLean
    Gustavo Di Pietro
    Holger Frey
    Hugh Cole-Baker
    Isabella Stephens
    Jacob Swanson
    Jasper Lievisse Adriaanse
    Jimisola Laursen
    Jiri Benc
    Johann Miller
    Jonathan Robson
    Josh Bleecher Snyder
    Julia Evans
    Justin Clift
    Karl Malmros
    Kevin Valk
    Konstantinos Smanis
    Kyriakos Oikonomakos
    Lance Eftink
    Legorooj
    Lukas Berk
    Martin von Zweigbergk
    Mathieu Bridon
    Mathieu Pillard
    Matthaus Woolard
    Matěj Cepl
    Maxwell G
    Michał Górny
    Na'aman Hirschfeld
    Nicolas Rybowski
    Nicolás Sanguinetti
    Nikita Kartashov
    Nikolai Zujev
    Nils Philippsen
    Noah Fontes
    Or Hayat
    Óscar San José
    Patrick Lühne
    Paul Wagland
    Peter Dave Hello
    Phil Schleihauf
    Philippe Ombredanne
    Ram Rachum
    Remy Suen
    Ridge Kennedy
    Rodrigo Bistolfi
    Ross Nicoll
    Rui Abreu Ferreira
    Rui Chen
    Sandro Jäckel
    Saul Pwanson
    Sebastian Hamann
    Shane Turner
    Sheeo
    Simone Mosciatti
    Soasme
    Steven Winfield
    Tad Hardesty
    Timo Röhling
    Victor Florea
    Vladimir Rutsky
    William Schueller
    Wim Jeantine-Glenn
    Yu Jianjian
    buhl
    chengyuhang
    earl
    odidev
